##
##  gmime.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2021 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_major  3.2
%define       V_minor  7
%define       V_perl   1.6

#   package information
Name:         gmime
Summary:      MIME Toolkit
URL:          http://spruce.sourceforge.net/gmime/
Vendor:       Jeffrey Stedfast
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        PLUS
Group:        Libraries
License:      LGPL
Version:      %{V_major}.%{V_minor}
Release:      20210902

#   package options
%option       with_perl  no

#   list of sources
Source0:      https://download.gnome.org/sources/gmime/%{V_major}/gmime-%{version}.tar.xz
Source1:      http://www.cpan.org/modules/by-module/MIME/MIME-Fast-%{V_perl}.tar.gz
Patch0:       gmime.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, gcc, make, pkgconfig
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  glib, libiconv, libidn, zlib
PreReq:       glib, libiconv, libidn, zlib
%if "%{with_perl}" == "yes"
BuildPreReq:  perl, perl-openpkg
PreReq:       perl
%endif

%description
    The GMime suite provides a core library and set of utilities which
    may be used for the creation and parsing of messages using the
    Multipurpose Internet Mail Extension (MIME).

%track
    prog gmime = {
        version   = %{version}
        url       = https://download.gnome.org/sources/gmime/
        regex     = (\d+\.[02468])/
        url       = https://download.gnome.org/sources/gmime/__NEWVER__/
        regex     = gmime-(\d+\.[02468]\.\d+)\.tar\.xz
    }
    prog gmime:MIME-Fast = {
        version   = %{V_perl}
        url       = http://www.cpan.org/modules/by-module/MIME/
        regex     = MIME-Fast-(__VER__)\.tar\.gz
    }

%prep
    %setup -q
    %setup -q -D -T -a 1
    %patch -p0

%build
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    GREP="grep" \
    ./configure \
        --prefix=%{l_prefix} \
        --datadir=%{l_prefix}/share/gmime \
        --disable-gtk-doc \
        --disable-shared
    %{l_make} %{l_mflags -O}
%if "%{with_perl}" == "yes"
    %{l_prefix}/bin/perl-openpkg prepare
    %{l_prefix}/bin/perl-openpkg -d MIME-Fast-%{V_perl} configure build
%endif

%install
    %{l_make} %{l_mflags} install \
        prefix=$RPM_BUILD_ROOT%{l_prefix} \
        exec_prefix=$RPM_BUILD_ROOT%{l_prefix} \
        datadir=$RPM_BUILD_ROOT%{l_prefix}/share/gmime
%if "%{with_perl}" == "yes"
    %{l_prefix}/bin/perl-openpkg -d MIME-Fast-%{V_perl} install
    %{l_prefix}/bin/perl-openpkg -F perl-openpkg-files fixate cleanup
%else
    >perl-openpkg-files
%endif
    rm -f $RPM_BUILD_ROOT%{l_prefix}/bin/uu*
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share/gmime
    mv $RPM_BUILD_ROOT%{l_prefix}/include/gmime-*/gmime \
       $RPM_BUILD_ROOT%{l_prefix}/include/gmime
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/include/gmime-*
    %{l_shtool} subst \
        -e 's;/include/gmime-[0-9.]*;/include;g' \
        $RPM_BUILD_ROOT%{l_prefix}/bin/gmime-config
    %{l_shtool} subst \
        -e 's;includedir}/gmime-[0-9.]*;includedir};g' \
        $RPM_BUILD_ROOT%{l_prefix}/lib/pkgconfig/gmime*.pc
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} `cat perl-openpkg-files`

%files -f files

%clean

